@@ -778,6 +778,11 @@ terminal_window_init (TerminalWindow *window)
       menus_have_icons = TRUE;
     }
  
+  g_signal_connect (window->priv->menubar,
+		    "can_activate_accel",
+		    G_CALLBACK (gtk_true),
+		    NULL);
+  
   accel_group = terminal_accels_get_group_for_widget (GTK_WIDGET (window));
   gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
   
